==> LCARS-SDK_16098.3.zip: LICENSE.md <==
LCARS SDK License 16098.3 (v3.0.0)
Author: Aric McGriff
Email: contact@lcarssdk.org
Website: http://www.lcarssdk.org
Date:04-09-216

Original Intellectual Property Ownership.
THE LCARS SDK IS MADE IN GOOD FAITH THAT THE ENVIRONMENT DOES NOT INFRINGE ON THE INTELLECTUAL PROPERTY OWNED BY PARAMOUNT/CBS TO WHOM STAR TREK AND RELATED MATERIALS ARE TRADEMARKED AND OWNED BY. ALL RELATED LCARS MATERIAL IS FOR THE JOY OF THE FANS AND TO HELP PROMOTE A QUALITY AND FUNCTIONAL LCARS ENVIRONMENT FOR THE STAR TREK FAN COMMUNITY.
THE AUTHOR CLAIMS NO OWNERSHIP ON THE NAME, DESIGN OR SOUNDS OF LCARS. THE AUTHOR NOR THE LCARS SDK ARE AFFILIATED WITH PARAMOUNT/CBS.

ORIGINAL DESIGN BY MIKE OKUDA ALONG WITH WORK FROM DOUG DREXLER AND OTHERS UNDER GENE RODDENBERRY.

Disclaimer of Warranty.
THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM “AS IS” WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.

Limitation of Liability.
IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Interpretation of Disclaimer of Warranty & Limitation of Liability.
If the disclaimer of warranty and limitation of liability provided
above cannot be given local legal effect according to their terms,
reviewing courts shall apply local law that most closely approximates
an absolute waiver of all civil liability in connection with the
Program, unless a warranty or assumption of liability accompanies a
copy of the Program in return for a fee.

*Warranty & Liability are cited from the Free Software Foundation, Inc. <http://fsf.org/> GPL3 License.

Definitions:
Author & Project Lead: Aric McGriff, creator of the LCARS SDK Project. Author and rights holder of the Code core within. To contact go to http://www.lcarssdk.org, email at contact@lcarssdk.org or socially connect via Facebook and Twitter.

LCARS SDK: A development kit and environment umbrella designed specifically for generating canon quality and functional LCARS interfaces within a webview.

Code core: Main code files required-provided for the LCARS SDK environment to function. These include both JavaScript and CSS languages.

Code core Files: lcarssdk.js – lcarssdk.css – sdktemplates.css – sdktemplates.js

Graphic Assets: Static, vector based representations of an LCARS interface(s) released within the LCARS SDK.

For-Profit: Any person(s), group(s) or legal entity who, through their routine process, uses, hosts or distribution of the LCARS SDK or any affiliated code that generates revenue connected with/utilizes the LCARS SDK or associated services.

Licensed 3rd Party: A person(s), group(s) or legal entity that is in a current ownership of an active license agreement with Paramount/CBS.

User: A person(s), group(s) or legal entity that only interacts with a final front end experience.

Developer: A person(s), group(s) or legal entity that creates, adapts or donates to the Code core.

Addons: Singular, self-contained that extend the functionality of the Code Core.

Addons Included: Scroll Button (scrollbutton.css/scrollbutton.js)

Module: A derivative work utilizing the LCARS SDK. Contains project specific code and generally extended features usability. A module is dependant upon the Code core not the other way around.

LCARS-NV: Provided application environment.

TERMS AND CONDITIONS
1. For-Profit use is prohibited. The LCARS SDK is for Non-Profit use only.
1.a For Licensed 3rd Party queries contact the Author/Project Lead for use of the Code core of the LCARS SDK.

2. The LCARS SDK does not cost money to obtain or use.  The source is visible/modifiable. Under no conditions shall any right to the Code core, Graphic assets, Addons or other associated first party materials transfer to a third party that uses, modifies or releases modified versions of LCARS SDK.

3. The LCARS SDK may not be licensed or sub-licensed without the express permission of the Author. The Author may not license the LCARS SDK for For-Profit use without express permission of Paramounts/CBS.

4. The LCARS SDK, its Author/Project Lead or any other associated relationships are not responsible or liable for any custom Addons or Modules created by a third party not included directly included in the LCARS SDK umbrella environment.

5. The LCARS SDK source code is available to allow the greatest control over its implementation use. By chance that a 3rd Party is negatively impacting the LCARS SDK environment or violating any other term and conditions concerning the LCARS SDK or related materials, at the discretion of the Author/Project Lead, the 3rd Party will be served a Cease & Desist, in writing. Take-down is immediate upon receiving the Cease & Desist.
5.a The LCARS-NV Project is a webview desktop and system bootable based project.  This appliction and operating system is provided as-is.

6. Included font provided by Jens. The .ttf file is directly from his site. Additional file types provided via the Font Squirrel service upon font authors permission.
6.a http://www.gtjlcars.de/LCARSindex/LCARSFONTS.htm
6.b Included font, lcarsunknown.ttf, has an unknown creator. The Author makes no claim of ownership and if original owner is found, please contact the Project Lead. Font is utilized for lowercase characters.

7. All released derivative work shall provide this license in whole and unmodified and use of the LCARS SDK identifiable.

8. This agreement may be periodically updated and adapted.

==> LCARS-SDK_16276.31.zip: LICENSE.md <==
LCARS SDK License 16276.31 (v3.1.0)
Author: Aric McGriff
Email: contact@lcarssdk.org
Website: http://www.lcarssdk.org
Date:10-02-2016

Original Intellectual Property Ownership.
THE LCARS SDK IS MADE IN GOOD FAITH THAT THE ENVIRONMENT DOES NOT INFRINGE ON THE INTELLECTUAL PROPERTY OWNED BY PARAMOUNT/CBS TO WHOM STAR TREK AND RELATED MATERIALS ARE TRADEMARKED AND OWNED BY. ALL RELATED LCARS MATERIAL IS FOR THE JOY OF THE FANS AND TO HELP PROMOTE A QUALITY AND FUNCTIONAL LCARS ENVIRONMENT FOR THE STAR TREK FAN COMMUNITY.
THE AUTHOR CLAIMS NO OWNERSHIP ON THE NAME, DESIGN OR SOUNDS OF LCARS. THE AUTHOR NOR THE LCARS SDK ARE AFFILIATED WITH PARAMOUNT/CBS.

ORIGINAL DESIGN BY MIKE OKUDA ALONG WITH WORK FROM DOUG DREXLER AND OTHERS UNDER GENE RODDENBERRY.

Disclaimer of Warranty.
THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM “AS IS” WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.

Limitation of Liability.
IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Interpretation of Disclaimer of Warranty & Limitation of Liability.
If the disclaimer of warranty and limitation of liability provided
above cannot be given local legal effect according to their terms,
reviewing courts shall apply local law that most closely approximates
an absolute waiver of all civil liability in connection with the
Program, unless a warranty or assumption of liability accompanies a
copy of the Program in return for a fee.

*Warranty & Liability are cited from the Free Software Foundation, Inc. <http://fsf.org/> GPL3 License.

Definitions:
Author & Project Lead: Aric McGriff, creator of the LCARS SDK Project. Author and rights holder of the Code core within. To contact go to http://www.lcarssdk.org, email at contact@lcarssdk.org or socially connect via Facebook and Twitter.

LCARS SDK: A development kit and environment umbrella designed specifically for generating canon quality and functional LCARS interfaces within a webview.

Core Code: Main code files required-provided for the LCARS SDK environment to function. These include both JavaScript and CSS languages.

Graphic Assets: Static, vector based representations of an LCARS interface(s) released within the LCARS SDK.

For-Profit: Any person(s), group(s) or legal entity who, through their routine process, uses, hosts or distribution of the LCARS SDK or any affiliated code that generates revenue connected with/utilizes the LCARS SDK or associated services.

Licensed 3rd Party: A person(s), group(s) or legal entity that is in a current ownership of an active license agreement with Paramount/CBS.

User: A person(s), group(s) or legal entity that only interacts with a final front end experience.

Developer: A person(s), group(s) or legal entity that creates, adapts or donates to the Code core.

Addons: Singular, self-contained that extend the functionality of the Code Core.

Addons Included: Scroll Button (scrollbutton.css/scrollbutton.js), Level Bar (levelBar.css/levelBar.js)

Templates: Base settings for basic LCARS elements.  Includes a js and css file.

Module: A derivative work utilizing the LCARS SDK. Contains project specific code and generally extended features usability. A module is dependant upon the Code core not the other way around.


TERMS AND CONDITIONS
1. For-Profit use is prohibited. The LCARS SDK is for Non-Profit use only.
1.a For Licensed 3rd Party queries contact the Author/Project Lead for use of the Code core of the LCARS SDK.

2. The LCARS SDK does not cost money to obtain or use.  The source is visible/modifiable. Under no conditions shall any right to the Code core, Graphic assets, Addons or other associated first party materials transfer to a third party that uses, modifies or releases modified versions of LCARS SDK.

3. The LCARS SDK may not be licensed or sub-licensed without the express permission of the Author. The Author may not license the LCARS SDK for For-Profit use without express permission of Paramounts/CBS.

4. The LCARS SDK, its Author/Project Lead or any other associated relationships are not responsible or liable for any custom Addons or Modules created by a third party not included directly included in the LCARS SDK umbrella environment.

5. The LCARS SDK source code is available to allow the greatest control over its implementation use. By chance that a 3rd Party is negatively impacting the LCARS SDK environment or violating any other term and conditions concerning the LCARS SDK or related materials, at the discretion of the Author/Project Lead, the 3rd Party will be served a Cease & Desist, in writing. Take-down is immediate upon receiving the Cease & Desist.

6. Included font provided by Vernon Adams. Web ready font files provided via the Font Squirrel service upon font authors permission.
6.a https://www.fontsquirrel.com/fonts/antonio - Requires Agreeing to SIL License included along with the LCARS SDK.
6.b Included font, lcars-mono.ttf is Author created monospaced font based on the Antonio Bold font.

7. All released derivative work shall provide this license in whole and unmodified and use of the LCARS SDK identifiable.

8. This agreement may be periodically updated and adapted.
